#ifndef MessageBox_h
#define MessageBox_h


/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "RoundedRegion.h"
#include "ShadowLabel.h"
#include "TransparentWidget.h"

#include <QBasicTimer>
#include <QString>
#include <QTimerEvent>
#include <QList>
#include <QSharedPointer>
#include <QLabel>
#include <QLayout>
#include <QList>

//! notification dialog
class MessageBox: public Transparency::TransparentWidget
{

    Q_OBJECT

    public:

    //! constructor
    MessageBox( QWidget*, const QString& );

    //! destructor
    virtual ~MessageBox( void )
    {}

    //! add message to queue
    void addMessage( const QString& );

    //! hide from taskbar
    void hideFromTaskBar( void );

    protected:

    //! timer event
    virtual void timerEvent( QTimerEvent* );

    //! resize event [overloaded]
    virtual void resizeEvent( QResizeEvent* );

    //! paint event
    virtual void _paint( QPaintDevice&, const QRect& );

    //! render widget
    void _render( QPaintDevice&, QWidget&, const QRect& );

    private Q_SLOTS:

    //! update configuration
    void _updateConfiguration( void );

    //! update margins
    void _updateMargins( void );

    private:

    //! remove message based on timer Id
    bool _removeMessage( int );

    //! title label
    Transparency::ShadowLabel* titleLabel_;

    //! message data
    class Data: public Counter
    {
        public:

        //! constructor
        Data( QWidget* parent, const QString& message = QString() );

        //! destructor
        virtual ~Data( void )
        {}

        bool operator == (const Data& other ) const
        { return timer_->timerId() == other.timer_->timerId(); }

        //! message
        QLabel* messageLabel_;

        //! timer
        QSharedPointer<QBasicTimer> timer_;

    };

    //! messages
    //typedef QList<Data> MessageList;
    using MessageList = QList<Data>;
    MessageList messages_;

    //! main layout
    QVBoxLayout* mainLayout_;

    //! use svg
    bool useSvg_;

    //! round corners
    bool roundCorners_;

};

#endif
