/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QLabel>
#include <QLayout>

#include "TunnelWidget.h"
#include "AnimatedLineEditor.h"
#include "AnimatedTreeView.h"
#include "GridLayout.h"
#include "IconEngine.h"
#include "IconNames.h"

//___________________________________________________________
TunnelWidget::TunnelWidget( QWidget* parent ):
    QWidget( parent )
{

    Debug::Throw( "TunnelWidget::TunnelWidget.\n" );

    // vbox layout
    QVBoxLayout* vLayout = new QVBoxLayout();
    vLayout->setMargin(0);
    vLayout->setSpacing(5);
    setLayout( vLayout );

    // grid layout
    GridLayout* gridLayout( new GridLayout() );
    gridLayout->setMargin(0);
    gridLayout->setSpacing(5);
    gridLayout->setMaxCount(2);
    gridLayout->setColumnAlignment(0, Qt::AlignRight|Qt::AlignVCenter );
    vLayout->addLayout( gridLayout );
    vLayout->addStretch( 1 );

    QLabel* label;
    gridLayout->addWidget( label = new QLabel( tr( "Local Port:" ), this ) );
    gridLayout->addWidget( localPortSpinBox_ = new QSpinBox( this ) );
    localPortSpinBox_->setMinimum( 0 );
    localPortSpinBox_->setMaximum( 100000 );
    label->setBuddy( localPortSpinBox_ );

    gridLayout->addWidget( label = new QLabel( tr( "Host:" ), this ) );
    gridLayout->addWidget( hostEditor_ = new AnimatedLineEditor( this ) );
    label->setBuddy( hostEditor_ );

    gridLayout->addWidget( label = new QLabel( tr( "Remote Port:" ), this ) );
    gridLayout->addWidget( remotePortSpinBox_ = new QSpinBox( this ) );
    remotePortSpinBox_->setMinimum( 0 );
    remotePortSpinBox_->setMaximum( 100000 );
    label->setBuddy( remotePortSpinBox_ );


}


//________________________________________
void TunnelWidget::setAttributes( const Ssh::TunnelAttributes& attributes )
{
    Debug::Throw( "TunnelWidget::setAttributes.\n" );

    // update editors
    localPortSpinBox_->setValue( attributes.localPort() );
    remotePortSpinBox_->setValue( attributes.remotePort() );
    hostEditor_->setText( attributes.host() );

}

//________________________________________
Ssh::TunnelAttributes TunnelWidget::attributes( void ) const
{
    Debug::Throw( "TunnelWidget::attributes.\n" );
    Ssh::TunnelAttributes out;
    out.setLocalPort( localPortSpinBox_->value() );
    out.setRemotePort( remotePortSpinBox_->value() );
    out.setHost( hostEditor_->text() );
    return out;
}
